.\" -*- nroff -*- generated from .Rd format
.BG
.FN lines.variomodel
.TL
Line with a  Variogram Model
.DN
This function adds a theoretical and/or fitted variogram to the
current plot (typically a sample variogram). The variogram model to be
added is typically an output of a variogram estimation function, or a
model specified by the user.
.CS
lines.variomodel(obj, max.dist=obj$max.dist, length=100, ...)

.RA
.AG obj
an object (list) of the class `variomodel' containing
information about the variogram model parameters.
.AG max.dist
maximum distance (x-axis) to compute and draw the line
with the variogram model. The default is the distance defined in the
object `obj'.
.AG length
number of points between `0' and `max.dist' to
compute the values of the variogram model.
.AG \&...
other arguments to be passed to the function `lines'.
.RT
A line with a variogram model is added to a plot on the current
graphics device. No values returned.
.SH REFERENCES
Further information about `geoR/geoS' can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`plot.variogram', `lines.variogram',
`olsfit', `wlsfit', `likfit', `lines'.
.EX
sim <- grf(100, cov.pars=c(1, .3))
# generates simulated data
vario <- variog(sim)
# computes empirical variogram
plot(vario)
# plots the empirical variogram
vario.wls <- wlsfit(vario, ini=c(1, .3), fix.nugget = T)
# estimate parameters
lines(vario.wls)
# adds fitted model to the plot  

.KW spatial, aplot
.WR
