.\" -*- nroff -*- generated from .Rd format
.BG
.FN varcov.spatial
.TL
Computes Covariance Matrix and/or Related Results
.DN
This function computes the covariance matrix for a set of spatial
locations, for given parameters.
According to the input other results related to the covariance matrix,
such as decompositions, determinants, inverse. etc are returned.
.CS

varcov.spatial(coords = NULL, dists.lowertri = NULL,
               cov.model = c("exponential", "matern", "gaussian",
                             "spherical", "circular", "cubic", "wave", 
                             "powered.exponential", "cauchy",
                             "gneiting", "gneiting.matern", "pure.nugget"),
               kappa = NULL, nugget = 0,
               cov.pars = stop("no cov.pars argument"), 
               inv = FALSE, det = FALSE, func.inv = "cholesky",
               scaled = FALSE,  only.decomposition = FALSE,
               sqrt.inv = FALSE, test.decomp = FALSE, 
               only.inv.lower.diag = FALSE) 
.IP "" 

.RA
.AG coords
a n x 2 matrix with coordinates. If not provided
the argument `dists.lowertri' should be provided instead.
.AG dists.lowertri
a vector with the lower triangle of the matrix
of distances between data points. If not provided
the argument `coords' should be provided instead.
.AG cov.model
a string indicating the type of the correlation
function. See the documentation of `cov.spatial' for the
options for the correlation function model.
.AG kappa
additional parameter needed for some of the correlation
functions, namely:`"matern", "powered.exponential", "gneiting"' and
`"gneiting.matern"'.
.AG nugget
the value of the nugget parameter.
.AG cov.pars
a vector with 2 elements or a ns x 2 matrix with
the covariance parameters. The first element (if a vector) or first column (if a matrix) is the variance parameter sigma^2. The
second element or column is the correlation function parameter
phi. If a matrix is provided, each row corresponds to
the parameters of one spatial structure. Models with several structures
are sometimes called nested models in the geostatistical literature.
.AG inv
if `TRUE' the inverse of covariance
matrix is returned. Defaults to `FALSE'.
.AG det
if `TRUE' the  logarithmic of the square root of the
determinant of the covariance
matrix is returned. Defaults to `FALSE'.
.AG func.inv
algorithm used for the decomposition and inversion of the covariance
matrix. Options are `"chol"' for Choleski decomposition,
`"svd"' for singular value decomposition and `"eigen"' for
eigenvalues/eigenvectors decomposition. Defaults to `"chol"'.
.AG scaled
scales the covariance matrix. If `TRUE' the sill
parameter sigma^2 is set to 1. Defaults to `FALSE'.
.AG only.decomposition
if `TRUE' only the decomposition is
returned. Defaults to `FALSE'.
.AG sqrt.inv
if `TRUE' the square root of the inverse of  covariance
matrix is returned. Defaults to `FALSE'.
.AG test.decomp

.AG only.inv.lower.diag
if `TRUE' only the lower triangle and
the diagonal of the inverse of the covariance matrix is
returned. Defaults to `FALSE'.
.RT
The result is a list. The components will vary according to the input
options. Possible components of output include:
.IP "" 
.AG varcov
the covariance matrix.
.AG sqrt.varcov
a square root of the covariance matrix.
.AG lower.inverse
the lower triangle of the inverse of covariance matrix.
.AG diag.inverse
the diagonal of the inverse of covariance matrix.
.AG inverse
the inverse of covariance matrix.
.AG log.det.to.half
the logarithmic of the square root of the
determinant of the covariance matrix.
.AG sqrt.inverse
a square root of the inverse of covariance matrix.
.SH REFERENCES
Further information about `geoR/geoS' can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`cov.spatial', `chol',
`svd', `eigen'.
.KW spatial
.WR
